#
# spec file for package python-Shapely
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Shapely
Version:        2.0.4
Release:        3.1
Summary:        Geospatial geometries, predicates, and operations
License:        BSD-3-Clause
URL:            https://github.com/shapely/shapely
Source:         https://files.pythonhosted.org/packages/source/s/shapely/shapely-%{version}.tar.gz
# PATCH-FIX-UPSTREAM Fix incompatible pointer type passed to GEOSPolygonize_r
Patch:          https://github.com/shapely/shapely/pull/1945.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module numpy-devel >= 1.25}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
# SECTION test
BuildRequires:  %{python_module pytest}
# Don't test with matplotlib until 15.x has python311-matplotlib.
# (It's currently in devel:languages:python:backports but not in the Leap :Update repositories)
%if 0%{?suse_version} > 1500
BuildRequires:  %{python_module matplotlib}
%endif
# /SECTION
BuildRequires:  fdupes
BuildRequires:  geos-devel >= 3.5
BuildRequires:  python-rpm-macros
# Shapely calls the GEOS libs libgeos and libgeos_c via ctypes in python scripts, undetected by rpm ld analyzer.
# (libgeos_c1 is detected due to some Cython optimized lib, but libgeos3 is not)
# use requires_eq in order to be detectable by the python_subpackages rewriter
%requires_eq    %(rpm -q --requires geos-devel | grep libgeos)
Requires:       (python-numpy >= 1.14 with python-numpy < 3)
Provides:       python-shapely = %{version}-%{release}
Obsoletes:      python-shapely < %{version}-%{release}
%python_subpackages

%description
Shapely is a Python package for manipulation and analysis of
planar geometric objects. It is based on the GEOS (the
engine of PostGIS) and JTS (from which GEOS is ported) libraries.
Shapely is not concerned with data formats or coordinate systems,
but can be readily integrated with packages that are like WorldMill
and pyproj.

%prep
%autosetup -p1 -n shapely-%{version}

%build
CFLAGS="%{optflags} `geos-config --cflags` LDFLAGS=`geos-config --clibs`"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# make sure not to import the source dir without compiled shapely.vectorized during tests
mkdir testenv
cp -r shapely/tests setup.cfg testenv
pushd testenv
%pytest_arch -ra
popd

%files %{python_files}
%license LICENSE.txt
%doc CREDITS.txt README.rst docs/*
%{python_sitearch}/shapely
%{python_sitearch}/shapely-%{version}.dist-info

%changelog
* Tue Jul  9 2024 Steve Kowalik <steven.kowalik@suse.com>
- Remove upper bound on Cython, Cython 3 is supported.
* Wed May 29 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Cherry-pick upstream patch to fix build with GCC 14
  * https://github.com/shapely/shapely/pull/1945.patch
* Sun May  5 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.0.4
  * Fix bug in ``to_wkt`` with multiple empty Z geometries (#2012).
  * Fix bug in ``to_ragged_array`` for an array of Points with
    missing values (#2034).
  * Compatibility with numpy 2
- Release 2.0.3
  * Fix regression in the ``oriented_envelope`` ufunc to accept
    array-like input in case of GEOS<3.12 (#1929).
  * The binary wheels are not yet compatible with a future NumPy
    2.0 release, therefore a ``numpy<2`` upper pin was added to the
    requirements (#1972).
  * Upgraded the GEOS version in the binary wheel distributions to
    3.11.3.
* Sun Dec 17 2023 Ben Greiner <code@bnavigator.de>
- Enable sle15_python_module_pythons, but don't test with MPL
* Mon Nov 20 2023 Ana Guerrero <ana.guerrero@suse.com>
- Update to 2.0.2
  [#]# Bug fixes:
  * Fix regression in the (in)equality comparison (geom1 == geom2)
    using __eq__ to not ignore the z-coordinates (#1732).
  * Fix MultiPolygon() constructor to accept polygons without
    holes (#1850).
  * Fix minimum_rotated_rectangle (oriented_envelope) to
    always return the minimum area solution (instead of minimum
    width). In practice, it will use the GEOS implementation only
    for GEOS 3.12+, and for older GEOS versions fall back to
    the implementation that was included in Shapely < 2 (#1670).
  * Fix from_ragged_array to work with read-only array input
    (#1744).
  * Fix the handling of z coordinates shapely.ops.substring
    (#1699).
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.0.1
  [#]# Bug fixes:
  * Fix regression in the Polygon() constructor taking a sequence
    of Points (#1662).
  * Fix regression in the geometry constructors when passing
    decimal.Decimal coordinate values (#1707).
  * Fix STRtree() to not make the passed geometry array immutable
    as side-effect of the constructor (#1714).
  * Fix the directed keyword in shapely.ops.linemerge() (#1695).
  [#]# Improvements:
  * Expose the function to get a matplotlib Patch object from a
    (Multi)Polygon (without already plotting it) publicly as
    :func:shapely.plotting.patch_from_polygon (#1704).
- Release 2.0.0
  * Shapely version 2.0.0 is a major release featuring a complete
    refactor of the internals and new vectorized (element-wise)
    array operations providing considerable performance
    improvements (based on the developments in the PyGEOS package),
    along with several breaking API changes and many feature
    improvements.
  - Full release notes and detailed description:
  * https://shapely.readthedocs.io/en/latest/release/2.x.html
* Sat Oct  1 2022 andy great <andythe_great@pm.me>
- Update to version 1.8.4.
  * The new c_geom_p type caused a regression and has been removed
    (#1487).
- Update for version 1.8.3.
  * Deprecations:
  * The STRtree class will be changed in 2.0.0 and will not be
    compatible with the class in versions 1.8.x. This change
    obsoletes the deprecation announcement in 1.8a3 (below).
  * Bug fixes:
  * The signature for GEOSMinimumClearance has been corrected,
    fixing an issue affecting aarch64-darwin (#1480)
  * Return and arg types have been corrected and made more strict
    for area, length, and distance properties.
  * A new c_geom_p type has been created to replace c_void_p when
    calling GEOS functions (#1479).
  * An incorrect polygon-line intersection (#1427) has been fixed
    in GEOS 3.10.3,mwhich will be included in wheels published
    to PyPI.
  * GEOS buffer parameters are now destroyed, fixing a memory
    leak (#1440).
- Remove patch, fix upstream.
  Shapely-issue1436-ef380ba-geos311.patch
* Tue Jul 19 2022 Ben Greiner <code@bnavigator.de>
- Add Shapely-issue1436-ef380ba-geos311.patch
  * gh#shapely/shapely#1436 -- work around issue with geos 3.11.0
* Mon Jun 20 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.8.2
  - Make Polygons and MultiPolygons closed by definition, like
    LinearRings. Resolves #1246.
  - Perform frozen app check for GEOS before conda env check on
    macos as we already do on linux (#1301).
  - Fix leak of GEOS coordinate sequence in nearest_points reported
    in #1098.
- Release 1.8.1
  * Wheels for 1.8.1 published on PyPI include GEOS 3.10.2. This
    version is the best version of GDAL yet. Discrepancies in
    behavior compared to previous versions are considered to be
    improvements.
  * Shapely 1.8.1 works with Pythons 3.6-3.10.
  * Require Cython >= 0.29.24 to support Python 3.10 (#1224).
  * Fix array_interface_base (#1235).
- Fix libgeos* runtime requirement undetected due to the ctypes
  load
* Mon Jan 10 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.8.0
  * Shapely 1.8.0 is a transitional version. There are a few bug
    fixes and new features, but it largely exists to warn about the
    upcoming changes in 2.0.0. See the new migration guide for more
    details on how to update your code from Shapely 1.8 to 2.0.
  * Shapely 1.8.0 supports only Python versions >= 3.6. The release
    is compatible with GEOS versions 3.6-3.10.
  * Deprecations: The following functions and geometry attributes
    and methods will be removed in version 2.0.0.
  - ops.cascaded_union
  - BaseGeometry.empty
  - BaseGeometry.ctypes and __array_interface__
  - multi-part geometry __len__
  - setting custom attributes on geometry objects
  - BaseGeometry.almost_exact
  - Deprecation warnings will be emitted in 1.8.0 when any of
    these features are used.
  * The deprecated to_wkb and to_wkt methods of BaseGeometry have
    been removed.
  * The STRtree nearest* methods now take an optional argument that
    specifies exclusion of the input geometry from results (#1115).
  * A GeometryTypeError has been added to shapely.errors and is
    consistently raised instead of TypeError or ValueError as in
    version 1.7. For backwards compatibility, the new exception
    will derive from TypeError and Value error until version 2.0
    (#1099).
  * The STRtree class constructor now takes an optional second
    argument, a sequence of objects to be stored in the tree. If
    not provided, the sequence indices of the geometries will be
    stored, as before (#1112).
  * The STRtree class has new query_geoms, query_items,
    nearest_geom, and nearest_item methods (#1112). The query and
    nearest methods remain as aliases for query_geoms and
    nearest_geom.
  * A normalize method has been added to geometry classes, exposing
    the GEOSNormalize algorithm (#1090).
  * STRtree instances have a new default capacity of 10 items per
    node (#1070).
  * The new shapely.ops.voronoi_diagram computes the Voronoi
    Diagram of a geometry or geometry collection (#833, #851).
  * shapely.validation.make_valid fixes invalid geometries (#883).
- Drop Shapely-fix-svg-collection-pr1042.patch
* Sat Apr 17 2021 Ben Greiner <code@bnavigator.de>
- Don't use and test NumPy for python36 flavor: not available on
  Tumbleweed (NEP29)
- Make sure to test shapely.vectorized on remaining flavors by
  changing the working dir.
* Sat Jan  9 2021 Benjamin Greiner <code@bnavigator.de>
- Add Shapely-fix-svg-collection-pr1042.patch
  gh#Toblerity/Shapely#1042 to fix failing test due to newer
  matplotlib version (and GEOS?)
* Sun Jan  3 2021 Benjamin Greiner <code@bnavigator.de>
- Skip Python2 build. It is not supported by upstream anymore and
  the unit tests in Leap fail because of it
- Let the %%python_subpackages macro take care of the correct
  provides/obsoletes flavors. (gh#openSUSE/python-rpm-macros#66)
* Sun Sep 27 2020 Hans-Peter Jansen <hpj@urpla.net>
- update to 1.7.1
  * ``STRtree`` now safely implements the pickle protocol (#915).^
  * Documentation has been added for ``minimum_clearance`` (#875, #874).
  * In ``STRtree.__del__()`` we guard against calling ``GEOSSTRtree_destroy``
  when the lgeos module has already been torn down on exit (#897, #830).
  * Documentation for the ``overlaps()`` method has been corrected (#920).
  * Correct the test in ``shapely.geometry.base.BaseGeometry.empty()`` to
  eliminate memory leaks like the one reported in #745.
  * Get free() not from libc but from the processes global symbols (#891),
  fixing a bug that manifests on OS X 10.15 and 10.16.
  * Extracting substrings from complex lines has been made more correct (#848,
  [#849]).
  * Splitting of complex geometries has been sped up by preparing the input
  geometry (#871).
  * Fix bug in concatenation of function argtypes (#866).
  * Improved documentation of STRtree usage (#857).
  * Improved handling for empty list or list of lists in GeoJSON coordinates
  (#852).
  * The polylabel algorithm now accounts for polygon holes (#851, #817).
* Wed Mar 11 2020 Ondřej Súkup <mimi.vx@gmail.com>
- drop fix-build-with-geos-3.8.0.patch
- update to 1.7.0
  * the buffer operation can now be single-sides
  * Nearest neighbor search has been added to STRtree
  * Removed vendorized `functools`
  * Disallow sequences of MultiPolygons as arguments to the MultiPolygon constructor
  * Added a new `EmptyGeometry` class to support GeoPandas
  * Added new `shapely.ops.substring` function
  * Added new `shapely.ops.clip_by_rect` function
  * shapely.wkb.dumps` now accepts an `srid` integer keyword argument
* Tue Mar 10 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build with upstream patch:
  * fix-build-with-geos-3.8.0.patch
* Thu Jun 13 2019 Todd R <toddrme2178@gmail.com>
- Run full unit tests
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 1.6.4.post2
  * Fix broken markup in this change log, which restores our nicely formatted
    readme on PyPI.
- Update to 1.6.4
  * Handle a ``TypeError`` that can occur when geometries are torn down (#473,
    [#528]).
- Update to 1.6.3
  * AttributeError is no longer raised when accessing __geo_interface__ of an
    empty polygon (#450).
  * ``asShape`` now handles empty coordinates in mappings as ``shape`` does
    (#542). Please note that ``asShape`` is likely to be deprecated in a future
    version of Shapely.
  * Check for length of LineString coordinates in speed mode, preventing crashes
    when using LineStrings with only one coordinate (#546).
- Update to 1.6.2
  * A 1.6.2.post1 release has been made to fix a problem with macosx wheels
    uploaded to PyPI.
- Update to 1.6.2
  * Splitting a linestring by one of its end points will now succeed instead of
    failing with a ``ValueError`` (#524, #533).
  * Missing documentation of a geometry's ``overlaps`` predicate has been added
    (#522).
- Update to 1.6.1
  * Avoid ``STRTree`` crashes due to dangling references (#505) by maintaining
    references to added geometries.
  * Reduce log level to debug when reporting on calls to ctypes ``CDLL()`` that
    don't succeed and are retried (#515).
  * Clarification: applications like GeoPandas that need an empty geometry object
    should use ``BaseGeometry()`` instead of ``Point()`` or ``Polygon()``. An
    ``EmptyGeometry`` class has been added in the master development branch and
    will be available in the next non-bugfix release.
- Update to 1.6.0
  + Bug fixes:
  * Passing a single coordinate to ``LineString()`` with speedups disabled now
    raises a ValueError as happens with speedups enabled. This resolves #509.
  * Isolate vendorized packaging in a _vendor directory, remove obsolete
    dist-info, and remove packaging from project requirements (resolves #468).
  * Level for log messages originating from the GEOS notice handler reduced from
    WARNING to INFO (#447).
  * Permit speedups to be imported again without Numpy (#444).
  * Implemented __array_interface__ for empty Points and LineStrings (#403).
  * Remove accidental hard requirement of Numpy (#431).
  * Shapely no longer configures logging in ``geos.py`` (#415).
  + New features:
  * Add support for GeometryCollection to shape and asShape functions (#422).
  * A new error derived from NotImplementedError, with a more useful message, is
    raised when the GEOS backend doesn't support a called method (#216).
  * The ``project()`` method of LineString has been extended to LinearRing
    geometries (#286).
  * A new ``minimum_rotated_rectangle`` attribute has been added to the base
    geometry class (#354).
  * A new ``shapely.ops.polylabel()`` function has been added. It
    computes a point suited for labeling concave polygons (#395).
  * A new ``shapely.ops.split()`` function has been added. It splits a
    geometry by another geometry of lesser dimension: polygon by line, line by
    point (#293, #371).
  * ``Polygon.from_bounds()`` constructs a Polygon from bounding coordinates
    (#392).
  * Support for testing with Numpy 1.4.1 has been added (#301).
  * Support creating all kinds of empty geometries from empty lists of Python
    objects (#397, #404).
  + Packaging:
  * Put Numpy in an optional requirement set named "vectorized" (#431).
  * Added new library search paths to assist Anaconda (#413).
  * geos-config will now be bypassed when NO_GEOS_CONFIG env var is set. This
    allows configuration of Shapely builds on Linux systems that for whatever
    reasons do not include the geos-config program (#322).
  * Packaging 16.7, a setup dependency, is vendorized (#314).
  * Infrastructure for building manylinux1 wheels has been added (#391).
  * The system's ``geos-config`` program is now only checked when ``setup.py``
    is executed, never during normal use of the module (#244).
  * Added new library search paths to assist PyInstaller (#382) and Windows
    (#343).
  + Refactoring:
  * Consolidation of exceptions in ``shapely.errors``.
  * ``UnsupportedGEOSVersionError`` is raised when GEOS < 3.3.0 (#407).
  * Switch from ``SingleSidedBuffer()`` to ``OffsetCurve()`` for GEOS >= 3.3
    (#270).
  * Cython speedups are now enabled by default (#252).
* Wed Jul 12 2017 toddrme2178@gmail.com
- Don't require ctypes, it is built-in.
- Fix backwards-compatibility provides.
* Wed Jul 12 2017 jengelh@inai.de
- Remove redundant wording from description.
* Tue Jul 11 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Fix source URL.
- Update to 1.5.17
  * Bug fix: eliminate memory leak in geom_factory() (#408).
  * Bug fix: remove mention of negative distances in parallel_offset and note
    that vertices of right hand offset lines are reversed (#284).
- Update to 1.5.16
  * Bug fix: eliminate memory leak when unpickling geometry objects (#384, #385).
  * Bug fix: prevent crashes when attempting to pickle a prepared geometry,
    raising ``PicklingError`` instead (#386).
  * Packaging: extension modules in the OS X wheels uploaded to PyPI link only
    libgeos_c.dylib now (you can verify and compare to previous releases with
    ``otool -L shapely/vectorized/_vectorized.so``).
- Update to 1.5.15
  * Bug fix: use uintptr_t to store pointers instead of long in _geos.pxi,
    preventing an overflow error (#372, #373). Note that this bug fix was
    erroneously reported to have been made in 1.5.14, but was not.
- Update to 1.5.14
  * Bug fix: use ``type()`` instead of ``isinstance()`` when evaluating geometry
    equality, preventing instances of base and derived classes from
    being mistaken for equals (#317).
  * Bug fix: ensure that empty geometries are created when constructors have no
    args (#332, #333).
  * Bug fix: support app "freezing" better on Windows by not relying on the
  ``__file__`` attribute (#342, #377).
  * Bug fix: ensure that empty polygons evaluate to be ``==`` (#355).
  * Bug fix: filter out empty geometries that can cause segfaults when creating
    and loading STRtrees (#345, #348).
  * Bug fix: no longer attempt to reuse GEOS DLLs already loaded by Rasterio
    or Fiona on OS X (#374, #375).
- Update to 1.5.13
  * Restore setup and runtime discovery and loading of GEOS shared library to
    state at version 1.5.9 (#326).
  * On OS X we try to reuse any GEOS shared library that may have been loaded
    via import of Fiona or Rasterio in order to avoid a bug involving the
    GEOS AbstractSTRtree (#324, #327).
- Update to 1.5.12
  * Remove configuration of root logger from libgeos.py (#312).
  * Skip test_fallbacks on Windows (#308).
  * Call setlocale(locale.LC_ALL, "") instead of resetlocale() on Windows when
    tearing down the locale test (#308).
  * Fix for Sphinx warnings (#309).
  * Addition of .cache, .idea, .pyd, .pdb to .gitignore (#310).
- Update to 1.5.11
  * Remove packaging module requirement added in 1.5.10 (#305). Distutils can't
    parse versions using 'rc', but if we stick to 'a' and 'b' we will be fine.
- Update to 1.5.10
  * Monkey patch affinity module by absolute reference (#299).
  * Raise TopologicalError in relate() instead of crashing (#294, #295, #303).
* Mon Jun 15 2015 bruno@ioda-net.ch
- Update to 1.5.9
  * Fix for 64 bit speedups compatibility (#274).
* Sun May 24 2015 bruno@ioda-net.ch
- Packaging
  * Added Provides lowercase
  * Added BuildRequire geos-devel Require geos
  * Added python-Cytools to build c extension
* Sun May 24 2015 bruno@ioda-net.ch
- Update to version 1.5.8 (2015-04-29)
  * Setup file encoding bug fix (#254).
  * Support for pyinstaller (#261).
  * Major prepared geometry operation fix for Windows (#268, #269).
  * Major fix for OS X binary wheel (#262).
- Changes since 1.2.18
  1.5.7 (2015-03-16)
    Test and fix buggy error and notice handlers (#249).
  1.5.6 (2015-02-02)
    Fix setup regression (#232, #234).
    SVG representation improvements (#233, #237).
  1.5.5 (2015-01-20)
    MANIFEST changes to restore _geox.pxi (#231).
  1.5.4 (2015-01-19)
    Fixed OS X binary wheel library load path (#224).
  1.5.3 (2015-01-12)
    Fixed ownership and potential memory leak in polygonize (#223).
    Wider release of binary wheels for OS X.
  1.5.2 (2015-01-04)
    Fail installation if GEOS dependency is not met, preventing update breakage (#218, #219).
  1.5.1 (2014-12-04)
    Restore geometry hashing (#209).
  1.5.0 (2014-12-02)
    Affine transformation speedups (#197).
    New == rich comparison (#195).
    Geometry collection constructor (#200).
    ops.snap() backed by GEOSSnap (#201).
    Clearer exceptions in cases of topological invalidity (#203).
  1.4.4 (2014-11-02)
    Proper conversion of numpy float32 vals to coords (#186).
  1.4.3 (2014-10-01)
    Fix for endianness bug in WKB writer (#174).
  1.4.2 (2014-09-29)
    Fix bungled 1.4.1 release (#176).
  1.4.1 (2014-09-23)
    Return of support for GEOS 3.2 (#176, #178).
  1.4.0 (2014-09-08)
    SVG representations for IPython’s inline image protocol.
    Efficient and fast vectorized contains().
    Change mitre_limit default to 5.0; raise ValueError with 0.0 (#139).
    Allow mix of tuples and Points in sped-up LineString ctor (#152).
    New STRtree class (#73).
    Add ops.nearest_points() (#147).
    Faster creation of geometric objects from others (cloning) (#165).
    Removal of tests from package.
  1.3.3 (2014-07-23)
    Allow single-part geometries as argument to ops.cacaded_union() (#135).
    Support affine transformations of LinearRings (#112).
  1.3.2 (2014-05-13)
    Let LineString() take a sequence of Points (#130).
  1.3.1 (2014-04-22)
    More reliable proxy cleanup on exit (#106).
    More robust DLL loading on all platforms (#114).
  1.3.0 (2013-12-31)
    Include support for Python 3.2 and 3.3 (#56), minimum version is now 2.6.
    Switch to GEOS WKT/WKB Reader/Writer API, with defaults changed to enable 3D output dimensions, and to ‘trim’ WKT output for GEOS >=3.3.0.
    Use GEOS version instead of GEOS C API version to determine library capabilities (#65).
  1.2.19 (2013-12-30)
    Add buffering style options (#55).
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 1.2.18
  + Add shapely.ops.transform.
  + Permit empty sequences in collection constructors (#49, #50).
  + Individual polygons in MultiPolygon.__geo_interface__ are changed
    to tuples to match Polygon.__geo_interface__ (#51).
  + Add shapely.ops.polygonize_full (#57).
- Changes between 1.2.17 and 1.2.16
  + Avoid circular import between wkt/wkb and geometry.base by moving calls
    to GEOS serializers to the latter module.
  + Set _ndim when unpickling (issue #6).
  + Don't install DLLs to Python's DLL directory (#37).
  + Add affinity module of affine transformation (#31).
  + Fix NameError that blocked installation with PyPy (#40, #41).
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 1.2.16:
  + Add ops.unary_union function.
  + Alias ops.cascaded_union to ops.unary_union when GEOS CAPI >= (1,7,0).
  + Add geos_version_string attribute to shapely.geos.
  + Ensure parent is set when child geometry is accessed.
  + Generate _speedups.c using Cython when building from repo when missing,
    stale, or the build target is "sdist".
  + The is_simple predicate of invalid, self-intersecting linear rings now
    returns ``False``.
  + Remove VERSION.txt from repo, it's now written by the distutils setup script
    with value of shapely.__version__.
- Changes from version 1.2.15:
  + Eliminate numerical sensitivity in a method chaining test (Debian bug
    [#663210]).
  + Account for cascaded union of random buffered test points being a polygon
    or multipolygon (Debian bug #666655).
  + Use Cython to build speedups if it is installed.
  + Avoid stumbling over SVN revision numbers in GEOS C API version strings.
* Thu Feb 23 2012 saschpe@suse.de
- Update to version 1.2.14:
  + A geometry's coords property is now sliceable, yielding a list of coordinate
    values.
  + Homogeneous collections are now sliceable, yielding a new collection of the
    same type.
* Thu Dec 15 2011 saschpe@suse.de
- Minor spec file cleanup:
  * Ran spec-cleaner
  * Use original tarball
  * Don't use --record-rpm (only SUSE)
  sc
* Thu Dec 15 2011 j.verdoold@gmail.com
- Updated to 1.2.13
* Wed Sep 30 2009 cfarrell1980@gmail.com
- Updated to 1.0.13
* Thu May 28 2009 cfarrell1980@gmail.com
- Initial import
